@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2008 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -118,6 +118,26 @@ gboolean gtkut_font_can_load(const gchar *str)
 		pango_font_description_free(desc);
 	}
 
+	return can_load;
+#elif defined(__APPLE__)
+	PangoFontDescription *desc;
+	PangoContext *context;
+	PangoFont *font;
+	gboolean can_load = FALSE;
+
+	desc = pango_font_description_from_string(str);
+	if (desc) {
+		context = gdk_pango_context_get_for_screen
+			(gdk_screen_get_default());
+		font = pango_context_load_font(context, desc);
+		if (font) {
+			can_load = TRUE;
+			g_object_unref(font);
+		}
+		g_object_unref(context);
+		pango_font_description_free(desc);
+	}
+
 	return can_load;
 #else
 	return FALSE;
@@ -895,7 +915,7 @@ void gtkut_text_buffer_insert_with_tag_by_name(GtkTextBuffer *buffer,
 	gtk_text_buffer_insert_with_tags_by_name
 		(buffer, iter, text, len, tag, NULL);
 
-	if (text[len - 1] != '\n') {
+	if (len > 0 && text[len - 1] != '\n') {
 		/* somehow returns invalid value first (bug?),
 		   so call it twice */
 		gtk_text_iter_get_chars_in_line(iter);
@@ -968,6 +988,21 @@ gboolean gtkut_window_modal_exist(void)
 	return exist;
 }
 
+/* ensure that the window is displayed on screen */
+void gtkut_window_move(GtkWindow *window, gint x, gint y)
+{
+	g_return_if_fail(window != NULL);
+
+	if (x < 0)
+		x = 0;
+	if (y < 0)
+		y = 0;
+	x %= gdk_screen_width();
+	y %= gdk_screen_height();
+
+	gtk_window_move(window, x, y);
+}
+
 void gtkut_widget_get_uposition(GtkWidget *widget, gint *px, gint *py)
 {
 	gint x, y;
